@@ -108,11 +108,10 @@ void BugzillaManager::setFeaturesForVersion(const QString& version)
     m_security = UseCookies;    // Used to have cookies for update-security.
 
     if (currentVersion >= MAKE_BUGZILLA_VERSION(4, 4, 3)) {
-        // Security method changes from cookies to tokens in v4.4.3.
-        m_security = UseTokens;
-    }
-    if (currentVersion >= MAKE_BUGZILLA_VERSION(4, 5, 0)) {
-        // Security method changes from tokens to password-only in v4.5.x.
+        // Security method changes from cookies to tokens in Bugzilla 4.4.3.
+	// BUT, tokens fail when kio_http sends any cookies found in KCookieJar,
+	// so go directly to passwords-only security (supported since Bugzilla
+	// 3.6 and will be enforced in Bugzilla 4.5.x).
         m_security = UsePasswords;
     }
 
@@ -192,7 +191,7 @@ void BugzillaManager::fetchBugReport(int bugnumber, QObject * jobOwner)
 
     KIO::Job * fetchBugJob = KIO::storedGet(url, KIO::Reload, KIO::HideProgressInfo);
     fetchBugJob->setParent(jobOwner);
-    connect(fetchBugJob, SIGNAL(finished(KJob*)) , this, SLOT(fetchBugJobFinished(KJob*)));
+    connect(fetchBugJob, &KIO::Job::finished, this, &BugzillaManager::fetchBugJobFinished);
 }
 
 
@@ -219,7 +218,7 @@ void BugzillaManager::searchBugs(const QStringList & products,
     stopCurrentSearch();
 
     m_searchJob = KIO::storedGet(QUrl(url) , KIO::Reload, KIO::HideProgressInfo);
-    connect(m_searchJob, SIGNAL(finished(KJob*)) , this, SLOT(searchBugsJobFinished(KJob*)));
+    connect(m_searchJob, &KIO::Job::finished, this, &BugzillaManager::searchBugsJobFinished);
 }
 
 void BugzillaManager::sendReport(const BugReport & report)
