@@ -57,6 +57,7 @@ View::View(QWindow *)
     m_config = KConfigGroup(KSharedConfig::openConfig("krunnerrc"), "General");
 
     setFreeFloating(m_config.readEntry("FreeFloating", false));
+    reloadConfig();
 
     new AppAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QLatin1String("/App"), this);
@@ -128,6 +129,8 @@ View::View(QWindow *)
     } else {
         setLocation(Plasma::Types::TopEdge);
     }
+
+    connect(qGuiApp, &QGuiApplication::focusWindowChanged, this, &View::slotFocusWindowChanged);
 }
 
 View::~View()
@@ -139,6 +142,13 @@ void View::objectIncubated()
     setMainItem(qobject_cast<QQuickItem *>(m_qmlObj->rootObject()));
 }
 
+void View::slotFocusWindowChanged()
+{
+    if (!QGuiApplication::focusWindow()) {
+        setVisible(false);
+    }
+}
+
 bool View::freeFloating() const
 {
     return m_floating;
@@ -164,6 +174,12 @@ void View::reloadConfig()
 {
     m_config.config()->reparseConfiguration();
     setFreeFloating(m_config.readEntry("FreeFloating", false));
+
+    const QStringList history = m_config.readEntry("history", QStringList());
+    if (m_history != history) {
+        m_history = history;
+        emit historyChanged();
+    }
 }
 
 bool View::event(QEvent *event)
@@ -313,4 +329,28 @@ void View::displayConfiguration()
     QProcess::startDetached(QStringLiteral("kcmshell5"), QStringList() << QStringLiteral("plasmasearch"));
 }
 
+QStringList View::history() const
+{
+    return m_history;
+}
+
+void View::addToHistory(const QString &item)
+{
+    if (item == QLatin1String("SESSIONS")) {
+        return;
+    }
+
+    m_history.removeOne(item);
+    m_history.prepend(item);
+
+    while (m_history.count() > 50) { // make configurable?
+        m_history.removeLast();
+    }
+
+    emit historyChanged();
+
+    m_config.writeEntry("history", m_history);
+    m_config.sync();
+}
+
 #include "moc_view.cpp"
