@@ -20,16 +20,21 @@
 #define DESKTOVIEW_H
 
 
-#include "plasmaquick/view.h"
+#include "plasmaquick/containmentview.h"
 #include "panelconfigview.h"
 #include <QtCore/qpointer.h>
 
+namespace KWayland
+{
+    namespace Client
+    {
+        class PlasmaShellSurface;
+    }
+}
 
-class DesktopView : public PlasmaQuick::View
+class DesktopView : public PlasmaQuick::ContainmentView
 {
     Q_OBJECT
-    //the qml part doesn't need to be able to write it, hide for now
-    Q_PROPERTY(bool dashboardShown READ isDashboardShown NOTIFY dashboardShownChanged)
 
     Q_PROPERTY(WindowType windowType READ windowType WRITE setWindowType NOTIFY windowTypeChanged)
 
@@ -53,9 +58,6 @@ public:
     explicit DesktopView(Plasma::Corona *corona, QScreen *targetScreen = 0);
     virtual ~DesktopView();
 
-    void setDashboardShown(bool shown);
-    bool isDashboardShown() const;
-
     void adaptToScreen();
     virtual void showEvent(QShowEvent*);
 
@@ -79,17 +81,17 @@ private Q_SLOTS:
 
 Q_SIGNALS:
     void stayBehindChanged();
-    void dashboardShownChanged();
     void windowTypeChanged();
 
 private:
     void coronaPackageChanged(const KPackage::Package &package);
     void ensureWindowType();
+    void setupWaylandIntegration();
 
     QPointer<PlasmaQuick::ConfigView> m_configView;
     QPointer<QScreen> m_oldScreen;
-    bool m_dashboardShown : 1;
     WindowType m_windowType;
+    KWayland::Client::PlasmaShellSurface *m_shellSurface;
 };
 
 #endif // DESKTOVIEW_H
