@@ -31,6 +31,12 @@
 #include <fixx11h.h>
 #endif
 
+#include <KWayland/Client/connection_thread.h>
+#include <KWayland/Client/registry.h>
+#include <KWayland/Client/shadow.h>
+#include <KWayland/Client/shm_pool.h>
+#include <KWayland/Client/surface.h>
+
 #include <qdebug.h>
 
 class PanelShadows::Private
@@ -44,6 +50,7 @@ public:
         , m_isX11(QX11Info::isPlatformX11())
 #endif
     {
+        setupWaylandIntegration();
     }
 
     ~Private()
@@ -54,17 +61,24 @@ public:
     }
 
     void freeX11Pixmaps();
+    void freeWaylandBuffers();
     void clearPixmaps();
     void setupPixmaps();
     Qt::HANDLE createPixmap(const QPixmap& source);
     void initPixmap(const QString &element);
     QPixmap initEmptyPixmap(const QSize &size);
     void updateShadow(const QWindow *window, Plasma::FrameSvg::EnabledBorders);
+    void updateShadowX11(const QWindow *window, Plasma::FrameSvg::EnabledBorders);
+    void updateShadowWayland(const QWindow *window, Plasma::FrameSvg::EnabledBorders);
     void clearShadow(const QWindow *window);
+    void clearShadowX11(const QWindow *window);
+    void clearShadowWayland(const QWindow *window);
     void updateShadows();
     void windowDestroyed(QObject *deletedObject);
     void setupData(Plasma::FrameSvg::EnabledBorders enabledBorders);
 
+    void setupWaylandIntegration();
+
     PanelShadows *q;
     QList<QPixmap> m_shadowPixmaps;
 
@@ -85,6 +99,14 @@ public:
     bool m_isX11;
 #endif
 
+    struct Wayland {
+        KWayland::Client::ShadowManager *manager = nullptr;
+        KWayland::Client::ShmPool *shmPool = nullptr;
+
+        QList<KWayland::Client::Buffer::Ptr> shadowBuffers;
+    };
+    Wayland m_wayland;
+
     QHash<Plasma::FrameSvg::EnabledBorders, QVector<unsigned long> > data;
     QHash<const QWindow *, Plasma::FrameSvg::EnabledBorders> m_windows;
 };
@@ -266,6 +288,11 @@ void PanelShadows::Private::setupPixmaps()
     m_emptyVerticalPix = initEmptyPixmap(QSize(1, q->elementSize("shadow-left").height()));
     m_emptyHorizontalPix = initEmptyPixmap(QSize(q->elementSize("shadow-top").width(), 1));
 
+    if (m_wayland.shmPool) {
+        for (auto it = m_shadowPixmaps.constBegin(); it != m_shadowPixmaps.constEnd(); ++it) {
+            m_wayland.shadowBuffers << m_wayland.shmPool->createBuffer(it->toImage());
+        }
+    }
 }
 
 
@@ -454,16 +481,31 @@ void PanelShadows::Private::clearPixmaps()
     m_emptyVerticalPix = QPixmap();
     m_emptyHorizontalPix = QPixmap();
 #endif
+    freeWaylandBuffers();
     m_shadowPixmaps.clear();
     data.clear();
 }
 
+void PanelShadows::Private::freeWaylandBuffers()
+{
+    m_wayland.shadowBuffers.clear();
+}
+
 void PanelShadows::Private::updateShadow(const QWindow *window, Plasma::FrameSvg::EnabledBorders enabledBorders)
 {
 #if HAVE_X11
-    if (!m_isX11) {
-        return;
+    if (m_isX11) {
+        updateShadowX11(window, enabledBorders);
     }
+#endif
+    if (m_wayland.manager) {
+        updateShadowWayland(window, enabledBorders);
+    }
+}
+
+void PanelShadows::Private::updateShadowX11(const QWindow *window, Plasma::FrameSvg::EnabledBorders enabledBorders)
+{
+#if HAVE_X11
     if (m_shadowPixmaps.isEmpty()) {
         setupPixmaps();
     }
@@ -478,30 +520,173 @@ void PanelShadows::Private::updateShadow(const QWindow *window, Plasma::FrameSvg
 //     qDebug() << "going to set the shadow of" << window->winId() << "to" << data;
     XChangeProperty(dpy, window->winId(), atom, XA_CARDINAL, 32, PropModeReplace,
                     reinterpret_cast<const unsigned char *>(data[enabledBorders].constData()), data[enabledBorders].size());
-#else
-    Q_UNUSED(window)
-    Q_UNUSED(enabledBorders)
 #endif
 }
 
+void PanelShadows::Private::updateShadowWayland(const QWindow *window, Plasma::FrameSvg::EnabledBorders enabledBorders)
+{
+    if (!m_wayland.shmPool) {
+        return;
+    }
+    if (m_wayland.shadowBuffers.isEmpty()) {
+        setupPixmaps();
+    }
+    // TODO: check whether the surface already has a shadow
+    KWayland::Client::Surface *surface = KWayland::Client::Surface::fromWindow(const_cast<QWindow*>(window));
+    if (!surface) {
+        return;
+    }
+    auto shadow = m_wayland.manager->createShadow(surface, surface);
+
+    //shadow-top
+    if (enabledBorders & Plasma::FrameSvg::TopBorder) {
+        shadow->attachTop(m_wayland.shadowBuffers.at(0));
+    }
+
+    //shadow-topright
+    if (enabledBorders & Plasma::FrameSvg::TopBorder &&
+        enabledBorders & Plasma::FrameSvg::RightBorder) {
+        shadow->attachTopRight(m_wayland.shadowBuffers.at(1));
+    }
+
+    //shadow-right
+    if (enabledBorders & Plasma::FrameSvg::RightBorder) {
+        shadow->attachRight(m_wayland.shadowBuffers.at(2));
+    }
+
+    //shadow-bottomright
+    if (enabledBorders & Plasma::FrameSvg::BottomBorder &&
+        enabledBorders & Plasma::FrameSvg::RightBorder) {
+        shadow->attachBottomRight(m_wayland.shadowBuffers.at(3));
+    }
+
+    //shadow-bottom
+    if (enabledBorders & Plasma::FrameSvg::BottomBorder) {
+        shadow->attachBottom(m_wayland.shadowBuffers.at(4));
+    }
+
+    //shadow-bottomleft
+    if (enabledBorders & Plasma::FrameSvg::BottomBorder &&
+        enabledBorders & Plasma::FrameSvg::LeftBorder) {
+        shadow->attachBottomLeft(m_wayland.shadowBuffers.at(5));
+    }
+
+    //shadow-left
+    if (enabledBorders & Plasma::FrameSvg::LeftBorder) {
+        shadow->attachLeft(m_wayland.shadowBuffers.at(6));
+    }
+
+    //shadow-topleft
+    if (enabledBorders & Plasma::FrameSvg::TopBorder &&
+        enabledBorders & Plasma::FrameSvg::LeftBorder) {
+        shadow->attachTopLeft(m_wayland.shadowBuffers.at(7));
+    }
+
+    QSize marginHint;
+    QMarginsF margins = QMarginsF(1, 1, 1, 1);
+    if (enabledBorders & Plasma::FrameSvg::TopBorder) {
+        marginHint = q->elementSize("shadow-hint-top-margin");
+        if (marginHint.isValid()) {
+            margins.setTop(marginHint.height());
+        } else {
+            margins.setTop(m_shadowPixmaps[0].height());
+        }
+    }
+
+    if (enabledBorders & Plasma::FrameSvg::RightBorder) {
+        marginHint = q->elementSize("shadow-hint-right-margin");
+        if (marginHint.isValid()) {
+            margins.setRight(marginHint.width());
+        } else {
+            margins.setRight(m_shadowPixmaps[2].width());
+        }
+    }
+
+    if (enabledBorders & Plasma::FrameSvg::BottomBorder) {
+        marginHint = q->elementSize("shadow-hint-bottom-margin");
+        if (marginHint.isValid()) {
+            margins.setBottom(marginHint.height());
+        } else {
+            margins.setBottom(m_shadowPixmaps[4].height());
+        }
+    }
+
+    if (enabledBorders & Plasma::FrameSvg::LeftBorder) {
+        marginHint = q->elementSize("shadow-hint-left-margin");
+        if (marginHint.isValid()) {
+            margins.setLeft(marginHint.width());
+        } else {
+            margins.setLeft(m_shadowPixmaps[6].width());
+        }
+    }
+
+    shadow->setOffsets(margins);
+    shadow->commit();
+    surface->commit(KWayland::Client::Surface::CommitFlag::None);
+}
+
 void PanelShadows::Private::clearShadow(const QWindow *window)
 {
 #if HAVE_X11
-    if (!m_isX11) {
-        return;
+    if (m_isX11) {
+        clearShadowX11(window);
     }
+#endif
+    if (m_wayland.manager) {
+        clearShadowWayland(window);
+    }
+}
+
+void PanelShadows::Private::clearShadowX11(const QWindow* window)
+{
+#if HAVE_X11
     Display *dpy = QX11Info::display();
     Atom atom = XInternAtom(dpy, "_KDE_NET_WM_SHADOW", False);
     XDeleteProperty(dpy, window->winId(), atom);
-#else
-    Q_UNUSED(window)
 #endif
 }
 
+void PanelShadows::Private::clearShadowWayland(const QWindow *window)
+{
+    KWayland::Client::Surface *surface = KWayland::Client::Surface::fromWindow(const_cast<QWindow*>(window));
+    if (!surface) {
+        return;
+    }
+    m_wayland.manager->removeShadow(surface);
+}
+
 bool PanelShadows::enabled() const
 {
      return hasElement("shadow-left");
 }
 
+void PanelShadows::Private::setupWaylandIntegration()
+{
+    if (!QGuiApplication::platformName().startsWith(QLatin1String("wayland"), Qt::CaseInsensitive)) {
+        return;
+    }
+    using namespace KWayland::Client;
+    ConnectionThread *connection = ConnectionThread::fromApplication(q);
+    if (!connection) {
+        return;
+    }
+    Registry *registry = new Registry(q);
+    registry->create(connection);
+    connect(registry, &Registry::shadowAnnounced, q,
+        [this, registry] (quint32 name, quint32 version) {
+            m_wayland.manager = registry->createShadowManager(name, version, q);
+            updateShadows();
+        }, Qt::QueuedConnection
+    );
+    connect(registry, &Registry::shmAnnounced, q,
+        [this, registry] (quint32 name, quint32 version) {
+            m_wayland.shmPool = registry->createShmPool(name, version, q);
+            updateShadows();
+        }, Qt::QueuedConnection
+    );
+    registry->setup();
+    connection->roundtrip();
+}
+
 #include "moc_panelshadows_p.cpp"
 
