@@ -23,12 +23,21 @@
 #include <Plasma/Theme>
 #include <QTimer>
 
-#include "plasmaquick/view.h"
+#include "plasmaquick/containmentview.h"
 #include "plasmaquick/configview.h"
 
 class ShellCorona;
 
-class PanelView : public PlasmaQuick::View
+namespace KWayland
+{
+    namespace Client
+    {
+        class PlasmaShellSurface;
+    }
+}
+
+class PanelView : public PlasmaQuick::ContainmentView
+
 {
     Q_OBJECT
     /**
@@ -167,6 +176,7 @@ private:
     void integrateScreen();
     bool containmentContainsPosition(const QPointF &point) const;
     QPointF positionAdjustedForContainment(const QPointF &point) const;
+    void setupWaylandIntegration();
 
     int m_offset;
     int m_maxLength;
@@ -183,6 +193,7 @@ private:
     QTimer m_unhideTimer;
     //only for the mask, not to actually paint
     Plasma::FrameSvg *m_background;
+    KWayland::Client::PlasmaShellSurface *m_shellSurface;
 
     static const int STRUTSTIMERDELAY = 200;
 };
