@@ -56,12 +56,13 @@ StandaloneAppCorona::StandaloneAppCorona(const QString &coronaPlugin, QObject *p
 
     m_desktopDefaultsConfig = KConfigGroup(KSharedConfig::openConfig(package.filePath("defaults")), "Desktop");
 
+    m_view = new DesktopView(this);
+
     connect(m_activityConsumer, SIGNAL(currentActivityChanged(QString)), this, SLOT(currentActivityChanged(QString)));
     connect(m_activityConsumer, SIGNAL(activityAdded(QString)), this, SLOT(activityAdded(QString)));
     connect(m_activityConsumer, SIGNAL(activityRemoved(QString)), this, SLOT(activityRemoved(QString)));
 
-    m_view = new DesktopView(this);
-    load();
+    connect(m_activityConsumer, SIGNAL(serviceStatusChanged(Consumer::ServiceStatus)), this, SLOT(load()));
 }
 
 StandaloneAppCorona::~StandaloneAppCorona()
@@ -178,7 +179,11 @@ void StandaloneAppCorona::activityRemoved(const QString &id)
 
 void StandaloneAppCorona::currentActivityChanged(const QString &newActivity)
 {
-//  qDebug() << "Activity changed:" << newActivity;
+    //qDebug() << "Activity changed:" << newActivity;
+
+    if (containments().isEmpty()) {
+        return;
+    }
 
     Plasma::Containment *c = createContainmentForActivity(newActivity, 0);
 
